Index: sdk/lib/_internal/pub/lib/src/global_packages.dart |
diff --git a/sdk/lib/_internal/pub/lib/src/global_packages.dart b/sdk/lib/_internal/pub/lib/src/global_packages.dart |
index 6ce58a775a445b9b8edc05e1fb1e796c16a2e829..d8c725033155af18cf9d74a56b42839717449c1b 100644 |
--- a/sdk/lib/_internal/pub/lib/src/global_packages.dart |
+++ b/sdk/lib/_internal/pub/lib/src/global_packages.dart |
@@ -660,9 +660,9 @@ $invocation %* |
if (snapshot != null) { |
batch += """ |
-rem The VM exits with code 255 if the snapshot version is out-of-date. |
+rem The VM exits with code 253 if the snapshot version is out-of-date. |
rem If it is, we need to delete it and run "pub global" manually. |
-if not errorlevel 255 ( |
+if not errorlevel 253 ( |
exit /b %errorlevel% |
) |
@@ -685,10 +685,10 @@ $invocation "\$@" |
if (snapshot != null) { |
bash += """ |
# The VM exits with code 255 if the snapshot version is out-of-date. |
# If it is, we need to delete it and run "pub global" manually. |
exit_code=\$? |
-if [ \$exit_code != 255 ]; then |
+if [ \$exit_code != 253 ]; then |
exit \$exit_code |
fi |
@@ -685,10 +685,10 @@ $invocation "\$@" |
if (snapshot != null) { |
bash += """ |
-# The VM exits with code 255 if the snapshot version is out-of-date. |
+# The VM exits with code 253 if the snapshot version is out-of-date. |
# If it is, we need to delete it and run "pub global" manually. |
exit_code=\$? |